@@ -27,6 +27,7 @@
 #' @param intercept Should intercept be fitted. Default is \code{intercept=TRUE}.
 #' @param standardize Logical flag for x variable standardization prior to fitting the model. The coefficients are always returned on the original scale. Default is \code{standardize=TRUE}.
 #' @param partial_method Indicate whether to use pairwise partial correlations, or shrinkage partial correlations.
+#' @param ridge_lambda Optional penalty for level-specific regressions (useful in high-dimensional case)
 #' @param ...  Additional arguments passed to \code{hclust}.
 #' @return An 'hfr' regression object.
 #' @author Johann Pfitzinger
@@ -57,6 +58,7 @@ hfr <- function(
   intercept = TRUE,
   standardize = TRUE,
   partial_method = c("pairwise", "shrinkage"),
+  ridge_lambda = 0,
   ...
   ) {
 
@@ -126,7 +128,7 @@ hfr <- function(
     xs <- x
   }
 
-  v = .get_level_reg(xs, y, wts, nvars, nobs, q, intercept, partial_method, ...)
+  v = .get_level_reg(xs, y, wts, nvars, nobs, q, intercept, partial_method, ridge_lambda, ...)
   meta_opt <- .get_meta_opt(y, kappa, nvars, nobs, var_names, standardize, intercept, standard_sd, standard_mean, v)
 
   beta <- drop(meta_opt$beta)
